@@ -108,6 +108,11 @@ class S3VFSFile:
         return True
 
     def xTruncate(self, newsize):
+        num_blocks = newsize // self._block_size
+        for obj in self._bucket.objects.filter(Prefix=self._key_prefix + "/"):
+            block = int(obj.key[-10:])
+            if block >= num_blocks:
+                obj.delete()
         return True
 
     def xWrite(self, data, offset):
